## Arches Querysets 1.0.0 Release Notes

A Django-native interface for Arches implementers to express application logic,
query business data, or build APIs using node and nodegroup aliases.

### Features

- Model managers providing QuerySets for resource and tile trees
- Lookups for filtering for most datatypes
- Bulk tile save operations
- Generic views via Django REST Framework
